/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.4.1 (build: 2013-08-01 15:32:38 UTC)
 *  on 2013-08-06 at 22:09:29 UTC 
 */

package com.google.api.services.dfareporting;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.api.client.json.JsonString;
import com.google.common.base.Preconditions;

/**
 * Service definition for Dfareporting (v1.3).
 *
 * <p>
 * Lets you create, run and download reports.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/doubleclick-advertisers/reporting/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link DfareportingRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Dfareporting extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.2-beta"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.2-beta of google-api-client to run version " +
        "1.13.2-beta of the DFA Reporting API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "dfareporting/v1.3/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Dfareporting(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Dfareporting(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the DimensionValues collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Dfareporting dfareporting = new Dfareporting(...);}
   *   {@code Dfareporting.DimensionValues.List request = dfareporting.dimensionValues().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public DimensionValues dimensionValues() {
    return new DimensionValues();
  }

  /**
   * The "dimensionValues" collection of methods.
   */
  public class DimensionValues {

    /**
     * Retrieves list of report dimension values for a list of filters.
     *
     * Create a request for the method "dimensionValues.query".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Query#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param content the {@link com.google.api.services.dfareporting.model.DimensionValueRequest}
     * @return the request
     */
    public Query query(Long profileId, com.google.api.services.dfareporting.model.DimensionValueRequest content) throws java.io.IOException {
      Query result = new Query(profileId, content);
      initialize(result);
      return result;
    }

    public class Query extends DfareportingRequest<com.google.api.services.dfareporting.model.DimensionValueList> {

      private static final String REST_PATH = "userprofiles/{profileId}/dimensionvalues/query";

      /**
       * Retrieves list of report dimension values for a list of filters.
       *
       * Create a request for the method "dimensionValues.query".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Query#execute()} method to invoke the remote operation.
       * <p> {@link Query#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param content the {@link com.google.api.services.dfareporting.model.DimensionValueRequest}
       * @since 1.13
       */
      protected Query(Long profileId, com.google.api.services.dfareporting.model.DimensionValueRequest content) {
        super(Dfareporting.this, "POST", REST_PATH, content, com.google.api.services.dfareporting.model.DimensionValueList.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public Query setAlt(String alt) {
        return (Query) super.setAlt(alt);
      }

      @Override
      public Query setFields(String fields) {
        return (Query) super.setFields(fields);
      }

      @Override
      public Query setKey(String key) {
        return (Query) super.setKey(key);
      }

      @Override
      public Query setOauthToken(String oauthToken) {
        return (Query) super.setOauthToken(oauthToken);
      }

      @Override
      public Query setPrettyPrint(Boolean prettyPrint) {
        return (Query) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Query setQuotaUser(String quotaUser) {
        return (Query) super.setQuotaUser(quotaUser);
      }

      @Override
      public Query setUserIp(String userIp) {
        return (Query) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA user profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Query setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The value of the nextToken from the previous result page. */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The value of the nextToken from the previous result page.
       */
      public String getPageToken() {
        return pageToken;
      }

      /** The value of the nextToken from the previous result page. */
      public Query setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Maximum number of results to return. */
      @com.google.api.client.util.Key
      private Integer maxResults;

      /** Maximum number of results to return.

     [minimum: 0] [maximum: 100]
       */
      public Integer getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return. */
      public Query setMaxResults(Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Files collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Dfareporting dfareporting = new Dfareporting(...);}
   *   {@code Dfareporting.Files.List request = dfareporting.files().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Files files() {
    return new Files();
  }

  /**
   * The "files" collection of methods.
   */
  public class Files {

    /**
     * Retrieves a report file by its report ID and file ID.
     *
     * Create a request for the method "files.get".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param reportId The ID of the report.
     * @param fileId The ID of the report file.
     * @return the request
     */
    public Get get(Long reportId, Long fileId) throws java.io.IOException {
      Get result = new Get(reportId, fileId);
      initialize(result);
      return result;
    }

    public class Get extends DfareportingRequest<com.google.api.services.dfareporting.model.File> {

      private static final String REST_PATH = "reports/{reportId}/files/{fileId}";

      /**
       * Retrieves a report file by its report ID and file ID.
       *
       * Create a request for the method "files.get".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param reportId The ID of the report.
       * @param fileId The ID of the report file.
       * @since 1.13
       */
      protected Get(Long reportId, Long fileId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.File.class);
        this.reportId = Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
        this.fileId = Preconditions.checkNotNull(fileId, "Required parameter fileId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private Long reportId;

      /** The ID of the report.
       */
      public Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Get setReportId(Long reportId) {
        this.reportId = reportId;
        return this;
      }

      /** The ID of the report file. */
      @com.google.api.client.util.Key
      private Long fileId;

      /** The ID of the report file.
       */
      public Long getFileId() {
        return fileId;
      }

      /** The ID of the report file. */
      public Get setFileId(Long fileId) {
        this.fileId = fileId;
        return this;
      }

    }
    /**
     * Lists files for a user profile.
     *
     * Create a request for the method "files.list".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA profile ID.
     * @return the request
     */
    public List list(Long profileId) throws java.io.IOException {
      List result = new List(profileId);
      initialize(result);
      return result;
    }

    public class List extends DfareportingRequest<com.google.api.services.dfareporting.model.FileList> {

      private static final String REST_PATH = "userprofiles/{profileId}/files";

      /**
       * Lists files for a user profile.
       *
       * Create a request for the method "files.list".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA profile ID.
       * @since 1.13
       */
      protected List(Long profileId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.FileList.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** The DFA profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA profile ID. */
      public List setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The field by which to sort the list. */
      @com.google.api.client.util.Key
      private String sortField;

      /** The field by which to sort the list. [default: LAST_MODIFIED_TIME]
       */
      public String getSortField() {
        return sortField;
      }

      /** The field by which to sort the list. */
      public List setSortField(String sortField) {
        this.sortField = sortField;
        return this;
      }

      /** Maximum number of results to return. */
      @com.google.api.client.util.Key
      private Integer maxResults;

      /** Maximum number of results to return.

     [minimum: 0] [maximum: 10]
       */
      public Integer getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return. */
      public List setMaxResults(Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** The value of the nextToken from the previous result page. */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The value of the nextToken from the previous result page.
       */
      public String getPageToken() {
        return pageToken;
      }

      /** The value of the nextToken from the previous result page. */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Order of sorted results, default is 'DESCENDING'. */
      @com.google.api.client.util.Key
      private String sortOrder;

      /** Order of sorted results, default is 'DESCENDING'. [default: DESCENDING]
       */
      public String getSortOrder() {
        return sortOrder;
      }

      /** Order of sorted results, default is 'DESCENDING'. */
      public List setSortOrder(String sortOrder) {
        this.sortOrder = sortOrder;
        return this;
      }

      /** The scope that defines which results are returned, default is 'MINE'. */
      @com.google.api.client.util.Key
      private String scope;

      /** The scope that defines which results are returned, default is 'MINE'. [default: MINE]
       */
      public String getScope() {
        return scope;
      }

      /** The scope that defines which results are returned, default is 'MINE'. */
      public List setScope(String scope) {
        this.scope = scope;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Reports collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Dfareporting dfareporting = new Dfareporting(...);}
   *   {@code Dfareporting.Reports.List request = dfareporting.reports().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Reports reports() {
    return new Reports();
  }

  /**
   * The "reports" collection of methods.
   */
  public class Reports {

    /**
     * Deletes a report by its ID.
     *
     * Create a request for the method "reports.delete".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param reportId The ID of the report.
     * @return the request
     */
    public Delete delete(Long profileId, Long reportId) throws java.io.IOException {
      Delete result = new Delete(profileId, reportId);
      initialize(result);
      return result;
    }

    public class Delete extends DfareportingRequest<Void> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}";

      /**
       * Deletes a report by its ID.
       *
       * Create a request for the method "reports.delete".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link Delete#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param reportId The ID of the report.
       * @since 1.13
       */
      protected Delete(Long profileId, Long reportId) {
        super(Dfareporting.this, "DELETE", REST_PATH, null, Void.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA user profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Delete setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private Long reportId;

      /** The ID of the report.
       */
      public Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Delete setReportId(Long reportId) {
        this.reportId = reportId;
        return this;
      }

    }
    /**
     * Retrieves a report by its ID.
     *
     * Create a request for the method "reports.get".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param reportId The ID of the report.
     * @return the request
     */
    public Get get(Long profileId, Long reportId) throws java.io.IOException {
      Get result = new Get(profileId, reportId);
      initialize(result);
      return result;
    }

    public class Get extends DfareportingRequest<com.google.api.services.dfareporting.model.Report> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}";

      /**
       * Retrieves a report by its ID.
       *
       * Create a request for the method "reports.get".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param reportId The ID of the report.
       * @since 1.13
       */
      protected Get(Long profileId, Long reportId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.Report.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA user profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Get setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private Long reportId;

      /** The ID of the report.
       */
      public Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Get setReportId(Long reportId) {
        this.reportId = reportId;
        return this;
      }

    }
    /**
     * Creates a report.
     *
     * Create a request for the method "reports.insert".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param content the {@link com.google.api.services.dfareporting.model.Report}
     * @return the request
     */
    public Insert insert(Long profileId, com.google.api.services.dfareporting.model.Report content) throws java.io.IOException {
      Insert result = new Insert(profileId, content);
      initialize(result);
      return result;
    }

    public class Insert extends DfareportingRequest<com.google.api.services.dfareporting.model.Report> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports";

      /**
       * Creates a report.
       *
       * Create a request for the method "reports.insert".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link Insert#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param content the {@link com.google.api.services.dfareporting.model.Report}
       * @since 1.13
       */
      protected Insert(Long profileId, com.google.api.services.dfareporting.model.Report content) {
        super(Dfareporting.this, "POST", REST_PATH, content, com.google.api.services.dfareporting.model.Report.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA user profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Insert setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

    }
    /**
     * Retrieves list of reports.
     *
     * Create a request for the method "reports.list".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @return the request
     */
    public List list(Long profileId) throws java.io.IOException {
      List result = new List(profileId);
      initialize(result);
      return result;
    }

    public class List extends DfareportingRequest<com.google.api.services.dfareporting.model.ReportList> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports";

      /**
       * Retrieves list of reports.
       *
       * Create a request for the method "reports.list".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @since 1.13
       */
      protected List(Long profileId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.ReportList.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA user profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public List setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The field by which to sort the list. */
      @com.google.api.client.util.Key
      private String sortField;

      /** The field by which to sort the list. [default: LAST_MODIFIED_TIME]
       */
      public String getSortField() {
        return sortField;
      }

      /** The field by which to sort the list. */
      public List setSortField(String sortField) {
        this.sortField = sortField;
        return this;
      }

      /** Maximum number of results to return. */
      @com.google.api.client.util.Key
      private Integer maxResults;

      /** Maximum number of results to return.

     [minimum: 0] [maximum: 10]
       */
      public Integer getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return. */
      public List setMaxResults(Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /** The value of the nextToken from the previous result page. */
      @com.google.api.client.util.Key
      private String pageToken;

      /** The value of the nextToken from the previous result page.
       */
      public String getPageToken() {
        return pageToken;
      }

      /** The value of the nextToken from the previous result page. */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Order of sorted results, default is 'DESCENDING'. */
      @com.google.api.client.util.Key
      private String sortOrder;

      /** Order of sorted results, default is 'DESCENDING'. [default: DESCENDING]
       */
      public String getSortOrder() {
        return sortOrder;
      }

      /** Order of sorted results, default is 'DESCENDING'. */
      public List setSortOrder(String sortOrder) {
        this.sortOrder = sortOrder;
        return this;
      }

      /** The scope that defines which results are returned, default is 'MINE'. */
      @com.google.api.client.util.Key
      private String scope;

      /** The scope that defines which results are returned, default is 'MINE'. [default: MINE]
       */
      public String getScope() {
        return scope;
      }

      /** The scope that defines which results are returned, default is 'MINE'. */
      public List setScope(String scope) {
        this.scope = scope;
        return this;
      }

    }
    /**
     * Updates a report. This method supports patch semantics.
     *
     * Create a request for the method "reports.patch".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param reportId The ID of the report.
     * @param content the {@link com.google.api.services.dfareporting.model.Report}
     * @return the request
     */
    public Patch patch(Long profileId, Long reportId, com.google.api.services.dfareporting.model.Report content) throws java.io.IOException {
      Patch result = new Patch(profileId, reportId, content);
      initialize(result);
      return result;
    }

    public class Patch extends DfareportingRequest<com.google.api.services.dfareporting.model.Report> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}";

      /**
       * Updates a report. This method supports patch semantics.
       *
       * Create a request for the method "reports.patch".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       * <p> {@link Patch#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param reportId The ID of the report.
       * @param content the {@link com.google.api.services.dfareporting.model.Report}
       * @since 1.13
       */
      protected Patch(Long profileId, Long reportId, com.google.api.services.dfareporting.model.Report content) {
        super(Dfareporting.this, "PATCH", REST_PATH, content, com.google.api.services.dfareporting.model.Report.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA user profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Patch setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private Long reportId;

      /** The ID of the report.
       */
      public Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Patch setReportId(Long reportId) {
        this.reportId = reportId;
        return this;
      }

    }
    /**
     * Runs a report.
     *
     * Create a request for the method "reports.run".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Run#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA profile ID.
     * @param reportId The ID of the report.
     * @return the request
     */
    public Run run(Long profileId, Long reportId) throws java.io.IOException {
      Run result = new Run(profileId, reportId);
      initialize(result);
      return result;
    }

    public class Run extends DfareportingRequest<com.google.api.services.dfareporting.model.File> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}/run";

      /**
       * Runs a report.
       *
       * Create a request for the method "reports.run".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Run#execute()} method to invoke the remote operation. <p>
       * {@link Run#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA profile ID.
       * @param reportId The ID of the report.
       * @since 1.13
       */
      protected Run(Long profileId, Long reportId) {
        super(Dfareporting.this, "POST", REST_PATH, null, com.google.api.services.dfareporting.model.File.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public Run setAlt(String alt) {
        return (Run) super.setAlt(alt);
      }

      @Override
      public Run setFields(String fields) {
        return (Run) super.setFields(fields);
      }

      @Override
      public Run setKey(String key) {
        return (Run) super.setKey(key);
      }

      @Override
      public Run setOauthToken(String oauthToken) {
        return (Run) super.setOauthToken(oauthToken);
      }

      @Override
      public Run setPrettyPrint(Boolean prettyPrint) {
        return (Run) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Run setQuotaUser(String quotaUser) {
        return (Run) super.setQuotaUser(quotaUser);
      }

      @Override
      public Run setUserIp(String userIp) {
        return (Run) super.setUserIp(userIp);
      }

      /** The DFA profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA profile ID. */
      public Run setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private Long reportId;

      /** The ID of the report.
       */
      public Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Run setReportId(Long reportId) {
        this.reportId = reportId;
        return this;
      }

      /** If set and true, tries to run the report synchronously. */
      @com.google.api.client.util.Key
      private Boolean synchronous;

      /** If set and true, tries to run the report synchronously.
       */
      public Boolean getSynchronous() {
        return synchronous;
      }

      /** If set and true, tries to run the report synchronously. */
      public Run setSynchronous(Boolean synchronous) {
        this.synchronous = synchronous;
        return this;
      }

    }
    /**
     * Updates a report.
     *
     * Create a request for the method "reports.update".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param profileId The DFA user profile ID.
     * @param reportId The ID of the report.
     * @param content the {@link com.google.api.services.dfareporting.model.Report}
     * @return the request
     */
    public Update update(Long profileId, Long reportId, com.google.api.services.dfareporting.model.Report content) throws java.io.IOException {
      Update result = new Update(profileId, reportId, content);
      initialize(result);
      return result;
    }

    public class Update extends DfareportingRequest<com.google.api.services.dfareporting.model.Report> {

      private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}";

      /**
       * Updates a report.
       *
       * Create a request for the method "reports.update".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       * <p> {@link Update#initialize(AbstractGoogleClientRequest)} must be called to initialize this
       * instance immediately after invoking the constructor. </p>
       *
       * @param profileId The DFA user profile ID.
       * @param reportId The ID of the report.
       * @param content the {@link com.google.api.services.dfareporting.model.Report}
       * @since 1.13
       */
      protected Update(Long profileId, Long reportId, com.google.api.services.dfareporting.model.Report content) {
        super(Dfareporting.this, "PUT", REST_PATH, content, com.google.api.services.dfareporting.model.Report.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        this.reportId = Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** The DFA user profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The DFA user profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The DFA user profile ID. */
      public Update setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

      /** The ID of the report. */
      @com.google.api.client.util.Key
      private Long reportId;

      /** The ID of the report.
       */
      public Long getReportId() {
        return reportId;
      }

      /** The ID of the report. */
      public Update setReportId(Long reportId) {
        this.reportId = reportId;
        return this;
      }

    }

    /**
     * An accessor for creating requests from the CompatibleFields collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Dfareporting dfareporting = new Dfareporting(...);}
     *   {@code Dfareporting.CompatibleFields.List request = dfareporting.compatibleFields().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public CompatibleFields compatibleFields() {
      return new CompatibleFields();
    }

    /**
     * The "compatibleFields" collection of methods.
     */
    public class CompatibleFields {

      /**
       * Returns the fields that are compatible to be selected in the respective sections of a report
       * criteria, given the fields already selected in the input report and user permissions.
       *
       * Create a request for the method "compatibleFields.query".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Query#execute()} method to invoke the remote operation.
       *
       * @param profileId The DFA user profile ID.
       * @param content the {@link com.google.api.services.dfareporting.model.Report}
       * @return the request
       */
      public Query query(Long profileId, com.google.api.services.dfareporting.model.Report content) throws java.io.IOException {
        Query result = new Query(profileId, content);
        initialize(result);
        return result;
      }

      public class Query extends DfareportingRequest<com.google.api.services.dfareporting.model.CompatibleFields> {

        private static final String REST_PATH = "userprofiles/{profileId}/reports/compatiblefields/query";

        /**
         * Returns the fields that are compatible to be selected in the respective sections of a report
         * criteria, given the fields already selected in the input report and user permissions.
         *
         * Create a request for the method "compatibleFields.query".
         *
         * This request holds the parameters needed by the the dfareporting server.  After setting any
         * optional parameters, call the {@link Query#execute()} method to invoke the remote operation.
         * <p> {@link Query#initialize(AbstractGoogleClientRequest)} must be called to initialize this
         * instance immediately after invoking the constructor. </p>
         *
         * @param profileId The DFA user profile ID.
         * @param content the {@link com.google.api.services.dfareporting.model.Report}
         * @since 1.13
         */
        protected Query(Long profileId, com.google.api.services.dfareporting.model.Report content) {
          super(Dfareporting.this, "POST", REST_PATH, content, com.google.api.services.dfareporting.model.CompatibleFields.class);
          this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
        }

        @Override
        public Query setAlt(String alt) {
          return (Query) super.setAlt(alt);
        }

        @Override
        public Query setFields(String fields) {
          return (Query) super.setFields(fields);
        }

        @Override
        public Query setKey(String key) {
          return (Query) super.setKey(key);
        }

        @Override
        public Query setOauthToken(String oauthToken) {
          return (Query) super.setOauthToken(oauthToken);
        }

        @Override
        public Query setPrettyPrint(Boolean prettyPrint) {
          return (Query) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Query setQuotaUser(String quotaUser) {
          return (Query) super.setQuotaUser(quotaUser);
        }

        @Override
        public Query setUserIp(String userIp) {
          return (Query) super.setUserIp(userIp);
        }

        /** The DFA user profile ID. */
        @com.google.api.client.util.Key
        private Long profileId;

        /** The DFA user profile ID.
         */
        public Long getProfileId() {
          return profileId;
        }

        /** The DFA user profile ID. */
        public Query setProfileId(Long profileId) {
          this.profileId = profileId;
          return this;
        }

      }

    }
    /**
     * An accessor for creating requests from the Files collection.
     *
     * <p>The typical use is:</p>
     * <pre>
     *   {@code Dfareporting dfareporting = new Dfareporting(...);}
     *   {@code Dfareporting.Files.List request = dfareporting.files().list(parameters ...)}
     * </pre>
     *
     * @return the resource collection
     */
    public Files files() {
      return new Files();
    }

    /**
     * The "files" collection of methods.
     */
    public class Files {

      /**
       * Retrieves a report file.
       *
       * Create a request for the method "files.get".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
       *
       * @param profileId The DFA profile ID.
       * @param reportId The ID of the report.
       * @param fileId The ID of the report file.
       * @return the request
       */
      public Get get(Long profileId, Long reportId, Long fileId) throws java.io.IOException {
        Get result = new Get(profileId, reportId, fileId);
        initialize(result);
        return result;
      }

      public class Get extends DfareportingRequest<com.google.api.services.dfareporting.model.File> {

        private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}/files/{fileId}";

        /**
         * Retrieves a report file.
         *
         * Create a request for the method "files.get".
         *
         * This request holds the parameters needed by the the dfareporting server.  After setting any
         * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
         * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param profileId The DFA profile ID.
         * @param reportId The ID of the report.
         * @param fileId The ID of the report file.
         * @since 1.13
         */
        protected Get(Long profileId, Long reportId, Long fileId) {
          super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.File.class);
          this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
          this.reportId = Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
          this.fileId = Preconditions.checkNotNull(fileId, "Required parameter fileId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public Get setAlt(String alt) {
          return (Get) super.setAlt(alt);
        }

        @Override
        public Get setFields(String fields) {
          return (Get) super.setFields(fields);
        }

        @Override
        public Get setKey(String key) {
          return (Get) super.setKey(key);
        }

        @Override
        public Get setOauthToken(String oauthToken) {
          return (Get) super.setOauthToken(oauthToken);
        }

        @Override
        public Get setPrettyPrint(Boolean prettyPrint) {
          return (Get) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public Get setQuotaUser(String quotaUser) {
          return (Get) super.setQuotaUser(quotaUser);
        }

        @Override
        public Get setUserIp(String userIp) {
          return (Get) super.setUserIp(userIp);
        }

        /** The DFA profile ID. */
        @com.google.api.client.util.Key
        private Long profileId;

        /** The DFA profile ID.
         */
        public Long getProfileId() {
          return profileId;
        }

        /** The DFA profile ID. */
        public Get setProfileId(Long profileId) {
          this.profileId = profileId;
          return this;
        }

        /** The ID of the report. */
        @com.google.api.client.util.Key
        private Long reportId;

        /** The ID of the report.
         */
        public Long getReportId() {
          return reportId;
        }

        /** The ID of the report. */
        public Get setReportId(Long reportId) {
          this.reportId = reportId;
          return this;
        }

        /** The ID of the report file. */
        @com.google.api.client.util.Key
        private Long fileId;

        /** The ID of the report file.
         */
        public Long getFileId() {
          return fileId;
        }

        /** The ID of the report file. */
        public Get setFileId(Long fileId) {
          this.fileId = fileId;
          return this;
        }

      }
      /**
       * Lists files for a report.
       *
       * Create a request for the method "files.list".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
       *
       * @param profileId The DFA profile ID.
       * @param reportId The ID of the parent report.
       * @return the request
       */
      public List list(Long profileId, Long reportId) throws java.io.IOException {
        List result = new List(profileId, reportId);
        initialize(result);
        return result;
      }

      public class List extends DfareportingRequest<com.google.api.services.dfareporting.model.FileList> {

        private static final String REST_PATH = "userprofiles/{profileId}/reports/{reportId}/files";

        /**
         * Lists files for a report.
         *
         * Create a request for the method "files.list".
         *
         * This request holds the parameters needed by the the dfareporting server.  After setting any
         * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
         * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
         * immediately after invoking the constructor. </p>
         *
         * @param profileId The DFA profile ID.
         * @param reportId The ID of the parent report.
         * @since 1.13
         */
        protected List(Long profileId, Long reportId) {
          super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.FileList.class);
          this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
          this.reportId = Preconditions.checkNotNull(reportId, "Required parameter reportId must be specified.");
        }

        @Override
        public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
          return super.executeUsingHead();
        }

        @Override
        public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
          return super.buildHttpRequestUsingHead();
        }

        @Override
        public List setAlt(String alt) {
          return (List) super.setAlt(alt);
        }

        @Override
        public List setFields(String fields) {
          return (List) super.setFields(fields);
        }

        @Override
        public List setKey(String key) {
          return (List) super.setKey(key);
        }

        @Override
        public List setOauthToken(String oauthToken) {
          return (List) super.setOauthToken(oauthToken);
        }

        @Override
        public List setPrettyPrint(Boolean prettyPrint) {
          return (List) super.setPrettyPrint(prettyPrint);
        }

        @Override
        public List setQuotaUser(String quotaUser) {
          return (List) super.setQuotaUser(quotaUser);
        }

        @Override
        public List setUserIp(String userIp) {
          return (List) super.setUserIp(userIp);
        }

        /** The DFA profile ID. */
        @com.google.api.client.util.Key
        private Long profileId;

        /** The DFA profile ID.
         */
        public Long getProfileId() {
          return profileId;
        }

        /** The DFA profile ID. */
        public List setProfileId(Long profileId) {
          this.profileId = profileId;
          return this;
        }

        /** The ID of the parent report. */
        @com.google.api.client.util.Key
        private Long reportId;

        /** The ID of the parent report.
         */
        public Long getReportId() {
          return reportId;
        }

        /** The ID of the parent report. */
        public List setReportId(Long reportId) {
          this.reportId = reportId;
          return this;
        }

        /** The field by which to sort the list. */
        @com.google.api.client.util.Key
        private String sortField;

        /** The field by which to sort the list. [default: LAST_MODIFIED_TIME]
         */
        public String getSortField() {
          return sortField;
        }

        /** The field by which to sort the list. */
        public List setSortField(String sortField) {
          this.sortField = sortField;
          return this;
        }

        /** Maximum number of results to return. */
        @com.google.api.client.util.Key
        private Integer maxResults;

        /** Maximum number of results to return.

       [minimum: 0] [maximum: 10]
         */
        public Integer getMaxResults() {
          return maxResults;
        }

        /** Maximum number of results to return. */
        public List setMaxResults(Integer maxResults) {
          this.maxResults = maxResults;
          return this;
        }

        /** The value of the nextToken from the previous result page. */
        @com.google.api.client.util.Key
        private String pageToken;

        /** The value of the nextToken from the previous result page.
         */
        public String getPageToken() {
          return pageToken;
        }

        /** The value of the nextToken from the previous result page. */
        public List setPageToken(String pageToken) {
          this.pageToken = pageToken;
          return this;
        }

        /** Order of sorted results, default is 'DESCENDING'. */
        @com.google.api.client.util.Key
        private String sortOrder;

        /** Order of sorted results, default is 'DESCENDING'. [default: DESCENDING]
         */
        public String getSortOrder() {
          return sortOrder;
        }

        /** Order of sorted results, default is 'DESCENDING'. */
        public List setSortOrder(String sortOrder) {
          this.sortOrder = sortOrder;
          return this;
        }

      }

    }
  }

  /**
   * An accessor for creating requests from the UserProfiles collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Dfareporting dfareporting = new Dfareporting(...);}
   *   {@code Dfareporting.UserProfiles.List request = dfareporting.userProfiles().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public UserProfiles userProfiles() {
    return new UserProfiles();
  }

  /**
   * The "userProfiles" collection of methods.
   */
  public class UserProfiles {

    /**
     * Gets one user profile by ID.
     *
     * Create a request for the method "userProfiles.get".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param profileId The user profile ID.
     * @return the request
     */
    public Get get(Long profileId) throws java.io.IOException {
      Get result = new Get(profileId);
      initialize(result);
      return result;
    }

    public class Get extends DfareportingRequest<com.google.api.services.dfareporting.model.UserProfile> {

      private static final String REST_PATH = "userprofiles/{profileId}";

      /**
       * Gets one user profile by ID.
       *
       * Create a request for the method "userProfiles.get".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @param profileId The user profile ID.
       * @since 1.13
       */
      protected Get(Long profileId) {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.UserProfile.class);
        this.profileId = Preconditions.checkNotNull(profileId, "Required parameter profileId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** The user profile ID. */
      @com.google.api.client.util.Key
      private Long profileId;

      /** The user profile ID.
       */
      public Long getProfileId() {
        return profileId;
      }

      /** The user profile ID. */
      public Get setProfileId(Long profileId) {
        this.profileId = profileId;
        return this;
      }

    }
    /**
     * Retrieves list of user profiles for a user.
     *
     * Create a request for the method "userProfiles.list".
     *
     * This request holds the parameters needed by the the dfareporting server.  After setting any
     * optional parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends DfareportingRequest<com.google.api.services.dfareporting.model.UserProfileList> {

      private static final String REST_PATH = "userprofiles";

      /**
       * Retrieves list of user profiles for a user.
       *
       * Create a request for the method "userProfiles.list".
       *
       * This request holds the parameters needed by the the dfareporting server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(AbstractGoogleClientRequest)} must be called to initialize this instance
       * immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(Dfareporting.this, "GET", REST_PATH, null, com.google.api.services.dfareporting.model.UserProfileList.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

    }

  }

  /**
   * Builder for {@link Dfareporting}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Dfareporting}. */
    @Override
    public Dfareporting build() {
      return new Dfareporting(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link DfareportingRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setDfareportingRequestInitializer(
        DfareportingRequestInitializer dfareportingRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(dfareportingRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
